<?php

namespace Litecms\Pack\Providers;

use Illuminate\Support\ServiceProvider;

class PackServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'pack');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'pack');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.pack', function ($app) {
            return $this->app->make('Litecms\Pack\Pack');
        });

                // Bind Pack to repository
        $this->app->bind(
            'Litecms\Pack\Interfaces\PackRepositoryInterface',
            \Litecms\Pack\Repositories\Eloquent\PackRepository::class
        );

        $this->app->register(\Litecms\Pack\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\Pack\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\Pack\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.pack'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/pack.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/pack')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/pack')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
